@@ -16,9 +16,9 @@ from pathlib import Path
 from typing import Dict, List, Tuple
 
 import pandas as pd
+import prql_python as prql
 import pygments
 import rich
-from enforce_typing import enforce_types
 from prompt_toolkit import prompt
 from prompt_toolkit.application import get_app
 from prompt_toolkit.auto_suggest import AutoSuggestFromHistory
@@ -32,15 +32,37 @@ from rich.table import Table
 from sqlalchemy import create_engine, inspect
 from sqlalchemy.exc import ResourceClosedError
 
-import pyprql.lang.prql as prql
 from pyprql import __version__ as pyprql_version
 from pyprql.cli.PRQLCompleter import PRQLCompleter
 from pyprql.cli.PRQLLexer import PRQLLexer
 from pyprql.cli.PRQLStyle import PRQLStyle
 
-bindings = KeyBindings()
 this_files_path = os.path.abspath(os.path.dirname(__file__))
-BOTTOM_TOOLBAR_TXT = prql.read_file("../assets/cli_bottom_toolbar.txt", this_files_path)
+
+
+def read_file(filename: str, path: str = this_files_path) -> str:
+    """Read a file and return its contents.
+
+    Parameters
+    ----------
+    filename : str
+        The file to read.
+    path : str
+        Default : the run path of the script.
+        The root folder.
+
+    Returns
+    -------
+    str
+        The contents of the file.
+    """
+    with open(path + os.sep + filename, "r") as f:
+        x = f.read()
+    return x
+
+
+bindings = KeyBindings()
+BOTTOM_TOOLBAR_TXT = read_file("../assets/cli_bottom_toolbar.txt")
 
 
 @bindings.add("c-l")
@@ -51,6 +73,17 @@ def clear_screen() -> None:
     print("\x1bc")
 
 
+def clean_column_names(data: pd.DataFrame) -> pd.DataFrame:
+    return (
+        data.columns.str.lower()
+        .str.strip()
+        .str.replace('"', "")
+        .str.replace(" ", "_")
+        .str.replace("(", "", regex=False)
+        .str.replace(")", "", regex=False)
+    )
+
+
 class CLI:
     """The command line interface object.
 
@@ -61,19 +94,22 @@ class CLI:
 
     Note
     ----
-    If ``connect_str`` is a path to a csv file,
-    then an in-memory sqlite database is created,
-    and the contents of the csv dumped to this database.
+    This additionally defines a number of default parameter values,
+    generally used to control state of the connection and prompt.
+
+    **has_one_blank** : bool, default False
+
+    **prompt_test** : str, default "PRQL>"
+
+    **command** : str, default ""
+
+    **sql_mode** : bool, default False
 
     Note
     ----
-        This additionally defines a number of default parameter values,
-        generally used to control state of the connection and prompt.
-
-        has_one_blank : bool, default False
-        prompt_test : str, default "PRQL>"
-        command : str, default ""
-        sql_mode : bool, default False
+    If ``connect_str`` is a path to a csv file,
+    then an in-memory sqlite database is created,
+    and the contents of the csv dumped to this database.
 
     Note
     ----
@@ -83,11 +119,14 @@ class CLI:
     """
 
     def __init__(self, connect_str: str = "") -> None:
+        global BOTTOM_TOOLBAR_TXT
         self.has_one_blank = False
         self.prompt_text = "PRQL> "
         self.command = ""
         self.sql_mode = False
-
+        BOTTOM_TOOLBAR_TXT += (
+            " Connected to " + connect_str[connect_str.rfind("/") + 1 :] + "."
+        )
         file = Path(connect_str)
         delims = {".csv": ",", ".tsv": "\t"}
         if file.suffix in delims.keys():
@@ -99,8 +138,7 @@ class CLI:
             data = pd.read_csv(
                 connect_str, sep=delims[file.suffix], header=0, index_col=None
             )
-            data.columns = data.columns.str.lower().str.replace(" ", "_")
-            # Dump to sql
+            data.columns = clean_column_names(data)
             data.to_sql(
                 "imported", self.engine, if_exists="fail", index=False, method="multi"
             )
@@ -119,7 +157,7 @@ class CLI:
     @staticmethod
     def print_usage() -> None:
         """Prints the usage information for the CLI."""
-        print(prql.read_file("../assets/cli_usage.txt", this_files_path))
+        print(read_file("../assets/cli_usage.txt"))
 
     def bottom_toolbar(self) -> List[Tuple[str, str]]:
         """Create bottom toolbar for prql prompt.
@@ -241,7 +279,6 @@ class CLI:
         highlighted = pygments.highlight(text, SqlLexer(), Formatter())
         return highlighted
 
-    @enforce_types
     def handle_input(self, _user_input: str) -> None:
         """Process user input.
 
@@ -262,20 +299,16 @@ class CLI:
             sys.exit(0)
         elif user_input == "examples":
             # That would likely increase maintainability
-            rich.print(prql.read_file("../assets/examples.txt", this_files_path))
+            rich.print(read_file("../assets/examples.txt"))
             return
         elif user_input == "?" or user_input == "help":
             rich.print(f"PyPRQL version: {pyprql_version}")
 
             if self.sql_mode:
-                rich.print(
-                    prql.read_file("../assets/sql_mode_help.txt", this_files_path)
-                )
+                rich.print(read_file("../assets/sql_mode_help.txt"))
 
             else:
-                rich.print(
-                    prql.read_file("../assets/prql_mode_help.txt", this_files_path)
-                )
+                rich.print(read_file("../assets/prql_mode_help.txt"))
                 self.prompt_text = "PRQL> "
 
             rich.print(
@@ -296,10 +329,10 @@ class CLI:
                 table.add_row(table_name)
             rich.print(table)
             return
-        elif user_input.startswith("show columns") or user_input.startswith("\d+"):
+        elif user_input.startswith("show columns") or user_input.startswith("\\d+"):
             key = "show columns"
             if key not in user_input:
-                key = "\d+"
+                key = "\\d+"
             table_name = user_input[key.__len__() + 1 :]
             print(table_name)
             # tables = self.engine.list_tables()
@@ -313,7 +346,7 @@ class CLI:
 
                 self.has_one_blank = False
                 sql = self.command
-                if "SELECT" in sql and "LIMIT" not in sql:
+                if "LIMIT" not in sql:
                     sql += " LIMIT 25"
 
                 self.prompt_text = "SQL> "
